encode_prefixed

Function encode_prefixed 

pub fn encode_prefixed(tag: Tag, payload: &[u8]) -> String
Encode payload as tag_<hexbody>_<hexchecksum>.

payload is the canonical byte encoding of the value (what to_bytes() returns). The body is its lowercase hex, identical to what to_hex() would emit.